Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(19)

Unified Diff: ash/system/chromeos/network/network_observer.h

Issue 15350002: Deprecate kAshDisableNewNetworkStatusArea (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/system/chromeos/network/network_observer.h
diff --git a/ash/system/chromeos/network/network_observer.h b/ash/system/chromeos/network/network_observer.h
index 45011c291eedf69344689c1241e00453368d9fc4..91bad8ce0aa94a486f329189e2b938d14af419ea 100644
--- a/ash/system/chromeos/network/network_observer.h
+++ b/ash/system/chromeos/network/network_observer.h
@@ -35,8 +35,6 @@ class NetworkObserver {
virtual ~NetworkObserver() {}
- virtual void OnNetworkRefresh(const NetworkIconInfo& info) = 0;
-
// Sets a network message notification.
// |message_type| identifies the type of message.
// |network_type| identifies the type of network involved.
@@ -48,13 +46,14 @@ class NetworkObserver {
const base::string16& title,
const base::string16& message,
const std::vector<base::string16>& links) = 0;
+
// Clears the message notification for |message_type|.
virtual void ClearNetworkMessage(MessageType message_type) = 0;
// Called when the user attempted to toggle Wi-Fi enable/disable.
// NOTE: Toggling is asynchronous and subsequent calls to query the current
// state may return the old value.
- virtual void OnWillToggleWifi() = 0;
+ virtual void RequestToggleWifi() = 0;
};
} // namespace ash
« no previous file with comments | « ash/system/chromeos/network/network_list_detailed_view_base.cc ('k') | ash/system/chromeos/network/network_state_notifier.cc » ('j') | no next file with comments »
@@ -48,13 +46,14 @@ class NetworkObserver {
// Clears the message notification for |message_type|.
virtual void ClearNetworkMessage(MessageType message_type) = 0;
- // Called when the user attempted to toggle Wi-Fi enable/disable.
+ // Called to request toggling Wi-Fi enable/disable, e.g. from an accelerator.
// NOTE: Toggling is asynchronous and subsequent calls to query the current
// state may return the old value.

Powered by Google App Engine
This is Rietveld 408576698